@@ -179,7 +179,8 @@ func (g *Git) Enabled() bool {
 		return true
 	}
 
-	if g.hasPoshGitStatus() {
+	source := g.props.GetString(Source, Cli)
+	if source == Pwsh && g.hasPoshGitStatus() {
 		return true
 	}
 
@@ -279,11 +280,7 @@ func (g *Git) shouldDisplay() bool {
 		return false
 	}
 
-	gitdir, err := g.env.HasParentFilePath(".git")
-	if err != nil {
-		if !g.props.GetBool(FetchBareInfo, false) {
-			return false
-		}
+	if g.props.GetBool(FetchBareInfo, false) {
 		g.realDir = g.env.Pwd()
 		bare := g.getGitCommandOutput("rev-parse", "--is-bare-repository")
 		if bare == trueStr {
@@ -291,6 +288,10 @@ func (g *Git) shouldDisplay() bool {
 			g.workingDir = g.realDir
 			return true
 		}
+	}
+
+	gitdir, err := g.env.HasParentFilePath(".git", true)
+	if err != nil {
 		return false
 	}
 
@@ -322,6 +323,13 @@ func (g *Git) setUser() {
 }
 
 func (g *Git) getBareRepoInfo() {
+	// we can still have a pointer to a bare repo
+	if file, err := g.env.HasParentFilePath(".git", true); err == nil && !file.IsDir {
+		content := g.FileContents(file.ParentFolder, ".git")
+		path := strings.TrimPrefix(content, "gitdir: ")
+		g.workingDir = filepath.Join(file.ParentFolder, path)
+	}
+
 	head := g.FileContents(g.workingDir, "HEAD")
 	branchIcon := g.props.GetString(BranchIcon, "\uE0A0")
 	g.Ref = strings.Replace(head, "ref: refs/heads/", "", 1)
@@ -329,6 +337,7 @@ func (g *Git) getBareRepoInfo() {
 	if !g.props.GetBool(FetchUpstreamIcon, false) {
 		return
 	}
+
 	g.Upstream = g.getGitCommandOutput("remote")
 	if len(g.Upstream) != 0 {
 		g.UpstreamIcon = g.getUpstreamIcon()
@@ -341,6 +350,7 @@ func (g *Git) setDir(dir string) {
 		g.Dir = strings.TrimSuffix(dir, `\.git`)
 		return
 	}
+
 	g.Dir = strings.TrimSuffix(dir, "/.git")
 }
 
@@ -350,8 +360,8 @@ func (g *Git) hasWorktree(gitdir *runtime.FileInfo) bool {
 	content = strings.Trim(content, " \r\n")
 	matches := regex.FindNamedRegexMatch(`^gitdir: (?P<dir>.*)$`, content)
 
-	if matches == nil || len(matches["dir"]) == 0 {
-		g.env.Debug("No matches found, directory isn't a worktree")
+	if len(matches) == 0 {
+		g.env.Debug("no matches found, directory isn't a worktree")
 		return false
 	}
 
@@ -359,22 +369,25 @@ func (g *Git) hasWorktree(gitdir *runtime.FileInfo) bool {
 	// to the mounted path
 	g.workingDir = g.convertToLinuxPath(matches["dir"])
 
+	// if we don't do this, we will identify the submodule as a worktree
+	isSubmodule := strings.Contains(g.workingDir, "/modules/")
+
 	// in worktrees, the path looks like this: gitdir: path/.git/worktrees/branch
-	// strips the last .git/worktrees part
-	// :ind+5 = index + /.git
-	ind := strings.LastIndex(g.workingDir, ".git/worktrees")
-	if ind > -1 {
+	// rootDir needs to become path/.git
+	// realDir needs to become path
+	ind := strings.LastIndex(g.workingDir, "/worktrees/")
+	if ind > -1 && !isSubmodule {
 		gitDir := filepath.Join(g.workingDir, "gitdir")
-		g.rootDir = g.workingDir[:ind+4]
-		g.realDir = strings.TrimSuffix(g.env.FileContent(gitDir), ".git\n")
+		g.rootDir = g.workingDir[:ind]
+		gitDirContent := g.env.FileContent(gitDir)
+		g.realDir = strings.TrimSuffix(gitDirContent, ".git\n")
 		g.IsWorkTree = true
 		return true
 	}
 
 	// in submodules, the path looks like this: gitdir: ../.git/modules/test-submodule
 	// we need the parent folder to detect where the real .git folder is
-	ind = strings.LastIndex(g.workingDir, ".git/modules")
-	if ind > -1 {
+	if isSubmodule {
 		g.rootDir = resolveGitPath(gitdir.ParentFolder, g.workingDir)
 		// this might be both a worktree and a submodule, where the path would look like
 		// this: path/.git/modules/module/path/worktrees/location. We cannot distinguish
@@ -389,6 +402,7 @@ func (g *Git) hasWorktree(gitdir *runtime.FileInfo) bool {
 			g.IsWorkTree = true
 			return true
 		}
+
 		g.realDir = g.rootDir
 		g.workingDir = g.rootDir
 		return true
