@@ -102,8 +102,8 @@ func Init(sh string) {
 	Shell = sh
 	Program = getTerminalName()
 
-	log.Debug("Terminal shell: %s", Shell)
-	log.Debug("Terminal program: %s", Program)
+	log.Debug("terminal program:", Program)
+	log.Debug("terminal shell:", Shell)
 
 	color.TrueColor = Program != AppleTerminal
 
@@ -166,8 +166,6 @@ func Pwd(pwdType, userName, hostName, pwd string) string {
 		pwd += `/`
 	}
 
-	pwd = strings.ReplaceAll(pwd, `\`, `/`)
-
 	switch pwdType {
 	case OSC7:
 		return fmt.Sprintf(formats.Osc7, hostName, pwd)
